aboutsummaryrefslogtreecommitdiffhomepage
path: root/examples/protos/keyvaluestore.proto
diff options
context:
space:
mode:
Diffstat (limited to 'examples/protos/keyvaluestore.proto')
-rw-r--r--examples/protos/keyvaluestore.proto10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/protos/keyvaluestore.proto b/examples/protos/keyvaluestore.proto
index 06b516a150..9b5e53d813 100644
--- a/examples/protos/keyvaluestore.proto
+++ b/examples/protos/keyvaluestore.proto
@@ -18,16 +18,16 @@ package keyvaluestore;
// Key value store service definition.
service KeyValueStore {
- // Provides a value for each key reques
- rpc GetValues (stream Key) returns (stream Value) {}
+ // Provides a value for each key request
+ rpc GetValues (stream Request) returns (stream Response) {}
}
// The request message containing the key
-message Key {
+message Request {
string key = 1;
}
-// The response message containing the greetings
-message Value {
+// The response message containing the value associated with the key
+message Response {
string value = 1;
}